# octobrowser

[![Croco Logo](https://i.ibb.co/G5Pjt6M/logo.png)](https://t.me/crocofactory)

[![PyPi Version](https://img.shields.io/pypi/v/octobrowser)](https://pypi.org/project/octobrowser/)
[![PyPI Downloads](https://img.shields.io/pypi/dm/octobrowser?label=downloads)](https://pypi.org/project/octobrowser/)
[![License](https://img.shields.io/github/license/blnkoff/octobrowser.svg)](https://pypi.org/project/octobrowser/)
[![Last Commit](https://img.shields.io/github/last-commit/blnkoff/octobrowser.svg)](https://pypi.org/project/octobrowser/)
[![Development Status](https://img.shields.io/pypi/status/octobrowser)](https://pypi.org/project/octobrowser/)

The package for interacting with API of anti-detect browser Octobrowser.

- **[Telegram channel](https://t.me/crocofactory)**
- **[Bug reports](https://github.com/blnkoff/octobrowser/issues)**

Source code is made available under the [MIT License](LICENSE)

# Installing octobrowser
To install `octobrowser` from PyPi, you can use that:

```shell
pip install octobrowser
```

To install `octobrowser` from GitHub, use that:

```shell
pip install git+https://github.com/blnkoff/octobrowser.git
```